@@ -183,13 +183,16 @@ class LegacyEvaluationItem(BaseModel):
     eval_set_id: str = Field(alias="evalSetId")
     created_at: str = Field(alias="createdAt")
     updated_at: str = Field(alias="updatedAt")
-    mocking_strategy: Optional[MockingStrategy] = Field(
-        default=None,
-        alias="mockingStrategy",
+    simulate_input: Optional[bool] = Field(default=None, alias="simulateInput")
+    input_generation_instructions: Optional[str] = Field(
+        default=None, alias="inputGenerationInstructions"
     )
-    input_mocking_strategy: Optional[InputMockingStrategy] = Field(
-        default=None,
-        alias="inputMockingStrategy",
+    simulate_tools: Optional[bool] = Field(default=None, alias="simulateInput")
+    simulation_instructions: Optional[str] = Field(
+        default=None, alias="simulationInstructions"
+    )
+    tools_to_simulate: list[EvaluationSimulationTool] = Field(
+        default_factory=list, alias="toolsToSimulate"
     )
 
 
@@ -211,12 +214,13 @@ class EvaluationSet(BaseModel):
 
     def extract_selected_evals(self, eval_ids) -> None:
         selected_evals: list[EvaluationItem] = []
+        remaining_ids = set(eval_ids)
         for evaluation in self.evaluations:
-            if evaluation.id in eval_ids:
+            if evaluation.id in remaining_ids:
                 selected_evals.append(evaluation)
-                eval_ids.remove(evaluation.id)
-        if len(eval_ids) > 0:
-            raise ValueError("Unknown evaluation ids: {}".format(eval_ids))
+                remaining_ids.remove(evaluation.id)
+        if len(remaining_ids) > 0:
+            raise ValueError("Unknown evaluation ids: {}".format(remaining_ids))
         self.evaluations = selected_evals
 
 
@@ -243,12 +247,13 @@ class LegacyEvaluationSet(BaseModel):
 
     def extract_selected_evals(self, eval_ids) -> None:
         selected_evals: list[LegacyEvaluationItem] = []
+        remaining_ids = set(eval_ids)
         for evaluation in self.evaluations:
-            if evaluation.id in eval_ids:
+            if evaluation.id in remaining_ids:
                 selected_evals.append(evaluation)
-                eval_ids.remove(evaluation.id)
-        if len(eval_ids) > 0:
-            raise ValueError("Unknown evaluation ids: {}".format(eval_ids))
+                remaining_ids.remove(evaluation.id)
+        if len(remaining_ids) > 0:
+            raise ValueError("Unknown evaluation ids: {}".format(remaining_ids))
         self.evaluations = selected_evals
 
 
