@@ -1,7 +1,6 @@
 # type: ignore
 import click
 
-from ..telemetry import track
 from .cli_pack import pack
 from .cli_publish import publish
 
@@ -21,10 +20,16 @@ from .cli_publish import publish
     flag_value="personal",
     help="Whether to publish to the personal workspace",
 )
+@click.option(
+    "--folder",
+    "-f",
+    "folder",
+    type=str,
+    help="Folder name to publish to (skips interactive selection)",
+)
 @click.argument("root", type=str, default="./")
-@track
-def deploy(root, feed):
+def deploy(root, feed, folder):
     """Pack and publish the project."""
     ctx = click.get_current_context()
     ctx.invoke(pack, root=root)
-    ctx.invoke(publish, feed=feed)
+    ctx.invoke(publish, feed=feed, folder=folder)
