@@ -21,8 +21,6 @@ from uipath._utils._bindings import ResourceOverwritesContext
 from uipath.eval._helpers import auto_discover_entrypoint
 from uipath.tracing import LlmOpsHttpExporter
 
-from .._utils.constants import ENV_JOB_ID
-from ..telemetry import track
 from ._utils._console import ConsoleLogger
 from ._utils._eval_set import EvalHelpers
 
@@ -88,7 +86,6 @@ def setup_reporting_prereq(no_report: bool) -> bool:
     default=False,
     help="Enable caching for LLM mocker responses",
 )
-@track(when=lambda *_a, **_kw: os.getenv(ENV_JOB_ID) is None)
 def eval(
     entrypoint: Optional[str],
     eval_set: Optional[str],
