@@ -8,7 +8,6 @@ import click
 from uipath.models.exceptions import EnrichedException
 
 from .._config import UiPathConfig
-from ..telemetry import track
 from ._push.sw_file_handler import SwFileHandler, UpdateEvent
 from ._utils._console import ConsoleLogger
 from ._utils._project_files import (
@@ -16,6 +15,7 @@ from ._utils._project_files import (
     ensure_config_file,
     get_project_config,
     validate_config,
+    validate_project_files,
 )
 from ._utils._studio_project import ProjectLockUnavailableError
 from ._utils._uv_helpers import handle_uv_operations
@@ -70,7 +70,6 @@ async def upload_source_files_to_project(
     is_flag=True,
     help="Skip running uv lock and exclude uv.lock from the package",
 )
-@track
 def push(root: str, nolock: bool) -> None:
     """Push local project files to Studio Web Project.
 
@@ -95,6 +94,7 @@ def push(root: str, nolock: bool) -> None:
     ensure_config_file(root)
     config = get_project_config(root)
     validate_config(config)
+    validate_project_files(root)
 
     project_id = UiPathConfig.project_id
     if not project_id:
