@@ -1,7 +1,6 @@
 # type: ignore
 import asyncio
 import os
-from os import environ as env
 from typing import Optional
 
 import click
@@ -12,10 +11,6 @@ from uipath._cli._utils._debug import setup_debugging
 from uipath._utils._bindings import ResourceOverwritesContext
 from uipath.tracing import JsonLinesFileExporter, LlmOpsHttpExporter
 
-from .._utils.constants import (
-    ENV_JOB_ID,
-)
-from ..telemetry import track
 from ._runtime._contracts import UiPathRuntimeError
 from ._utils._console import ConsoleLogger
 from .middlewares import Middlewares
@@ -63,7 +58,6 @@ console = ConsoleLogger()
     default=5678,
     help="Port for the debug server (default: 5678)",
 )
-@track(when=lambda *_a, **_kw: env.get(ENV_JOB_ID) is None)
 def run(
     entrypoint: Optional[str],
     input: Optional[str],
