@@ -6,6 +6,17 @@ from .buckets import Bucket, BucketFile
 from .connections import Connection, ConnectionMetadata, ConnectionToken, EventArguments
 from .context_grounding import ContextGroundingQueryResponse
 from .context_grounding_index import ContextGroundingIndex
+from .context_grounding_payloads import (
+    BaseSourceConfig,
+    BucketSourceConfig,
+    ConfluenceSourceConfig,
+    ConnectionSourceConfig,
+    DropboxSourceConfig,
+    GoogleDriveSourceConfig,
+    Indexer,
+    OneDriveSourceConfig,
+    SourceConfig,
+)
 from .errors import BaseUrlMissingError, SecretMissingError
 from .exceptions import IngestionInProgressException
 from .interrupt_models import (
@@ -23,6 +34,7 @@ from .queues import (
     TransactionItem,
     TransactionItemResult,
 )
+from .resource_catalog import Folder, Resource, ResourceType, Tag
 
 __all__ = [
     "Action",
@@ -52,4 +64,17 @@ __all__ = [
     "SecretMissingError",
     "Bucket",
     "BucketFile",
+    "Resource",
+    "Tag",
+    "Folder",
+    "ResourceType",
+    "BaseSourceConfig",
+    "BucketSourceConfig",
+    "ConfluenceSourceConfig",
+    "ConnectionSourceConfig",
+    "DropboxSourceConfig",
+    "GoogleDriveSourceConfig",
+    "OneDriveSourceConfig",
+    "SourceConfig",
+    "Indexer",
 ]
