@@ -2,7 +2,7 @@ import uuid
 from datetime import datetime
 from typing import Optional
 
-from pydantic import BaseModel, ConfigDict, Field
+from pydantic import BaseModel, ConfigDict, Field, field_serializer
 
 
 class Attachment(BaseModel):
@@ -17,9 +17,14 @@ class Attachment(BaseModel):
         use_enum_values=True,
         arbitrary_types_allowed=True,
         extra="allow",
-        json_encoders={datetime: lambda v: v.isoformat() if v else None},
     )
 
+    @field_serializer("creation_time", "last_modification_time", when_used="json")
+    def serialize_datetime(self, value):
+        if isinstance(value, datetime):
+            return value.isoformat() if value else None
+        return value
+
     name: str = Field(alias="Name")
     creation_time: Optional[datetime] = Field(default=None, alias="CreationTime")
     last_modification_time: Optional[datetime] = Field(
