@@ -91,6 +91,14 @@ def extract_agent_json_from_added_resources(request: Request) -> dict[str, Any]:
 class TestPush:
     """Test push command."""
 
+    def _create_required_files(self, exclude: list[str] | None = None):
+        required_files = ["uipath.json", "bindings.json", "entry-points.json"]
+        for file in required_files:
+            if exclude and file in exclude:
+                continue
+            with open(file, "w") as file:
+                file.write("{}")
+
     def test_push_without_uipath_json(
         self,
         runner: CliRunner,
@@ -100,6 +108,7 @@ class TestPush:
     ) -> None:
         """Test push when uipath.json is missing."""
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["uipath.json"])
             configure_env_vars(mock_env_vars)
             os.environ["UIPATH_PROJECT_ID"] = "123"
             with open("pyproject.toml", "w") as f:
@@ -111,19 +120,69 @@ class TestPush:
                 in result.output
             )
 
+    def test_push_without_required_files_shows_specific_missing(
+        self,
+        runner: CliRunner,
+        temp_dir: str,
+        project_details: ProjectDetails,
+        uipath_json_legacy: UiPathJson,
+        mock_env_vars: Dict[str, str],
+    ) -> None:
+        """Test push shows specific missing files when uipath.json and .uipath are missing."""
+        with runner.isolated_filesystem(temp_dir=temp_dir):
+            configure_env_vars(mock_env_vars)
+            os.environ["UIPATH_PROJECT_ID"] = "123"
+
+            self._create_required_files(exclude=["bindings.json", "entry-points.json"])
+
+            with open("pyproject.toml", "w") as f:
+                f.write(project_details.to_toml())
+
+            result = runner.invoke(cli, ["push", "./"])
+            assert result.exit_code == 1
+            # Should show exactly which file is missing
+            assert (
+                "Missing required files: 'bindings.json', 'entry-points.json'"
+                in result.output
+            )
+            assert "Please run 'uipath init'" in result.output
+
+    def test_push_with_only_enty_points_json_missing(
+        self,
+        runner: CliRunner,
+        temp_dir: str,
+        project_details: ProjectDetails,
+        mock_env_vars: Dict[str, str],
+    ) -> None:
+        """Test push when .uipath directory exists but uipath.json is missing."""
+        with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["entry-points.json"])
+
+            configure_env_vars(mock_env_vars)
+            os.environ["UIPATH_PROJECT_ID"] = "123"
+
+            with open("pyproject.toml", "w") as f:
+                f.write(project_details.to_toml())
+
+            result = runner.invoke(cli, ["push", "./"])
+            assert result.exit_code == 1
+            # Should show exactly which file is missing
+            assert "Missing required files: 'entry-points.json'" in result.output
+            assert "Please run 'uipath init'" in result.output
+
     def test_push_without_project_id(
         self,
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
     ) -> None:
         """Test push when UIPATH_PROJECT_ID is missing."""
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files()
             configure_env_vars(mock_env_vars)
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
@@ -136,7 +195,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -257,8 +316,7 @@ class TestPush:
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             # Create necessary files
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
 
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
@@ -307,7 +365,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -346,8 +404,17 @@ class TestPush:
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             # Create necessary files
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files(exclude=["entry-points.json"])
+
+            with open("entry-points.json", "w") as f:
+                json.dump(
+                    {
+                        "entryPoints": json.loads(uipath_json_legacy.to_json()).get(
+                            "entryPoints"
+                        )
+                    },
+                    f,
+                )
 
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
@@ -391,20 +458,13 @@ class TestPush:
             )
             assert "targetRuntime" in agent_json_content["metadata"]
             assert agent_json_content["metadata"]["targetRuntime"] == "python"
-            assert "inputSchema" in agent_json_content
-            assert "outputSchema" in agent_json_content
-            assert (
-                agent_json_content["inputSchema"]["type"]
-                == uipath_json.entry_points[0].input.type
-            )
-            assert "agent_1_output" in agent_json_content["outputSchema"]["properties"]
 
     def test_push_with_api_error(
         self,
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -421,10 +481,11 @@ class TestPush:
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             # Create necessary files
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
+
             with open("uv.lock", "w") as f:
                 f.write("")
 
@@ -442,7 +503,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -515,8 +576,7 @@ class TestPush:
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             # Create necessary files
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
 
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
@@ -555,7 +615,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -564,7 +624,7 @@ class TestPush:
         project_id = "test-project-id"
 
         # Set up exclusions - exclude a JSON file that would normally be included
-        uipath_json.settings.files_excluded = ["config.json"]
+        uipath_json_legacy.settings.files_excluded = ["config.json"]
 
         # Mock the project structure response (empty project)
         mock_structure = {
@@ -596,8 +656,10 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["uipath.json"])
+
             with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+                f.write(uipath_json_legacy.to_json())
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
@@ -626,7 +688,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -635,8 +697,8 @@ class TestPush:
         project_id = "test-project-id"
 
         # Set up both inclusion and exclusion for the same file
-        uipath_json.settings.files_included = ["conflicting.txt"]
-        uipath_json.settings.files_excluded = ["conflicting.txt"]
+        uipath_json_legacy.settings.files_included = ["conflicting.txt"]
+        uipath_json_legacy.settings.files_excluded = ["conflicting.txt"]
 
         # Mock the project structure response (empty project)
         mock_structure = {
@@ -668,8 +730,10 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["uipath.json"])
+
             with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+                f.write(uipath_json_legacy.to_json())
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
@@ -695,7 +759,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -704,7 +768,10 @@ class TestPush:
         project_id = "test-project-id"
 
         # Exclude root config.json and specific path subdir2/settings.json
-        uipath_json.settings.files_excluded = ["config.json", "subdir2/settings.json"]
+        uipath_json_legacy.settings.files_excluded = [
+            "config.json",
+            "subdir2/settings.json",
+        ]
 
         # Mock empty project structure
         mock_structure = {
@@ -735,8 +802,10 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["uipath.json"])
+
             with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+                f.write(uipath_json_legacy.to_json())
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
@@ -788,7 +857,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -797,7 +866,7 @@ class TestPush:
         project_id = "test-project-id"
 
         # Include root data.txt and specific path subdir1/config.txt
-        uipath_json.settings.files_included = ["data.txt", "subdir1/config.txt"]
+        uipath_json_legacy.settings.files_included = ["data.txt", "subdir1/config.txt"]
 
         # Mock empty project structure
         mock_structure = {
@@ -828,8 +897,10 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["uipath.json"])
+
             with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+                f.write(uipath_json_legacy.to_json())
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
@@ -883,7 +954,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -892,7 +963,7 @@ class TestPush:
         project_id = "test-project-id"
 
         # Exclude root-level "temp" directory and specific path "tests/old"
-        uipath_json.settings.directories_excluded = ["temp", "tests/old"]
+        uipath_json_legacy.settings.directories_excluded = ["temp", "tests/old"]
 
         # Mock empty project structure
         mock_structure = {
@@ -923,8 +994,10 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
+            self._create_required_files(exclude=["uipath.json"])
+
             with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+                f.write(uipath_json_legacy.to_json())
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
@@ -977,7 +1050,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
         monkeypatch: Any,
@@ -1035,8 +1108,8 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
             with open("main.py", "w") as f:
@@ -1055,7 +1128,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
         monkeypatch: Any,
@@ -1113,8 +1186,8 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
             with open("main.py", "w") as f:
@@ -1134,7 +1207,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
         monkeypatch: Any,
@@ -1207,8 +1280,8 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
             with open("main.py", "w") as f:
@@ -1230,7 +1303,7 @@ class TestPush:
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -1302,8 +1375,8 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
             with open("main.py", "w") as f:
@@ -1323,12 +1396,12 @@ class TestPush:
             assert "Updating 'main.py'" not in result.output
             assert "Updating 'helper.py'" not in result.output
 
-    def test_push_preserves_remote_coded_evals_when_no_local_evals(
+    def test_push_preserves_remote_evals_when_no_local_evals(
         self,
         runner: CliRunner,
         temp_dir: str,
         project_details: ProjectDetails,
-        uipath_json: UiPathJson,
+        uipath_json_legacy: UiPathJson,
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
@@ -1420,8 +1493,8 @@ class TestPush:
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
-            with open("uipath.json", "w") as f:
-                f.write(uipath_json.to_json())
+            self._create_required_files()
+
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
             with open("main.py", "w") as f:
